@@ -27,7 +27,7 @@ class AAlastriaAuthService(ABC):
 
     @staticmethod
     @abstractmethod
-    def get_request_session_serializer(subject_did: str) -> RequestSession:
+    def get_request_session_serializer() -> RequestSession:
         ...
 
     @staticmethod
