@@ -22,6 +22,7 @@ from alastria_service_client.validators import (
     OnlyNetworkValidator,
     Address,
 )
+from datetime import timedelta
 from alastria_identity.types import JwtToken, AlastriaToken
 from network_service_client.client import (
     AClient as ANetworkClient,
@@ -94,6 +95,7 @@ class AlastriaAuthService(AAlastriaAuthService):
     def get_request_session_serializer() -> RequestSession:
         rs: RequestSession = RequestSession(
             request_date=now(),
+            expiration_date=now() + timedelta(minutes=5),
             requested_by="",
             confirm_url="/alastria/alastria-auth/confirm",
         )
